library(rgeos)
library(sf)

####Analysis of all plumes####
setwd("C:/Wollongong/projects/Smoke_tradeoff/Smoke_plumes_data")
plumesall<-read_sf("plumes2003_20_250k.shp")

####Figure 2 (Histogram of plumes by month and year####
windows(6,5)
par(mfrow=c(2,2))
par(mar=c(3,4,0,0.5))
#Frequency of Fires, WF and HR by month
hrset<-subset(plumesall, FireType=="HR")
hist(hrset$month,xlab="",col=8,xlim=c(1,12),main="")
text(9,150,"(a) Prescribed v month",cex=0.9)
hist(hrset$year,xlab="",col="cornflowerblue",main="",nclass=20,xlim=c(2004,2020))
text(2008.5,100,"(c) Prescribed v year",cex=0.9)

wfset<-subset(plumesall,FireType=="WF")
hist(wfset$month,xlab="",col=8,xlim=c(1,12), main="")
title(xlab="Month",line=2)
text(6,145,"(b) Wildfire v month",cex=0.9)
hist(wfset$year,xlab="",col="cornflowerblue", main="",nclass=20,xlim=c(2004,2020))
title(xlab="Year",line=2)
text(2008,120,"(d) Wildfire v year",cex=0.9)


####Analysis of Plume v Monitor intersections####
setwd("C:/Wollongong/admin/students/Simin_Rahmani/Plumes_v3")
plumedat<-read.csv("plumes2021_aqatmos_v2.csv", stringsAsFactors = F)

####Figure 3: Number of monitors per fire####
sample<-as.data.frame(table(plumedat$PlumeArea))
windows(4,3)
par(mar=c(3,4,1,1))
hist(sample$Freq,xlab="",ylab="",col=8,main="")
title(xlab="Number of Monitors per Plume",line=2);title(ylab="Frequency",line=2)


####Figure 4: Distribution of PM values for daytime, previous day and nighttime####

windows(3,5)
par(mfrow=c(3,1))
par(mar=c(3,3,0.5,1))
subdat<-subset(plumedat,FireType=="HR")
h1<-hist(subdat$day_pm25,nclass=20,plot=F)
h2<-hist(subdat$night_pm25,nclass=20,plot=F)
h3<-hist(subdat$base_day_pm25,nclass=5,plot=F)
plot(h1,xlim=c(0,100),col=8,ylim=c(0,10),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(70,10,"(a) Prescribed, Daytime")
lines(c(25,25),c(0,100),lty=9,col=2)
plot(h2,xlim=c(0,100),col=8,ylim=c(0,10),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(70,10,"(c) Prescribed, Nighttime")
lines(c(25,25),c(0,100),lty=9,col=2)
plot(h3,xlim=c(0,100),col=8,ylim=c(0,10),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(65,10,"(e) Prescribed, Previous Daytime")
lines(c(25,25),c(0,300),lty=9,col=2)


subdat<-subset(plumedat,FireType=="WF")
h1<-hist(subdat$day_pm25,nclass=20,plot=F)
h2<-hist(subdat$night_pm25,nclass=20,plot=F)
h3<-hist(subdat$base_day_pm25,nclass=15,plot=F)
plot(h1,xlim=c(0,250),col=8,ylim=c(0,250),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(180,250,"(b) Wildfire, Daytime")
lines(c(25,25),c(0,250),lty=9,col=2)
plot(h2,xlim=c(0,250),col=8,ylim=c(0,320),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(180,300,"(d) Wildfire, Nighttime")
lines(c(25,25),c(0,250),lty=9,col=2)
plot(h3,xlim=c(0,250),col=8,ylim=c(0,300),main="",xlab="",ylab="")
title(xlab="PM 2.5",line=2); title(ylab="Frequency",line=2)
text(180,280,"(f) Wildfire, Previous Daytime")
lines(c(25,25),c(0,250),lty=9,col=2)

####Figure 5 and 6: basic plot of responses  ####
#Daytime (Figure 5)

windows(9,12)
par(mfrow=c(7,3))
par(mar=c(3,3,1,1))

wfsub<-subset(plumedat,FireType=="WF")
hrsub<-subset(plumedat,FireType=="HR")
wfexsub<-subset(plumedat,FireType=="WF" & Date < "2019-06-30")
ex2019sub<-subset(plumedat,Date < "2019-06-30")

bargraph.CI(5*floor((wfsub$day_temp)/5),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)
bargraph.CI(5*floor((wfexsub$day_temp)/5),wfexsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)
bargraph.CI(5*floor((hrsub$day_temp)/5),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)

bargraph.CI(20*floor((wfsub$day_rh)/20),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)
bargraph.CI(20*floor((wfsub$day_rh)/20),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)
bargraph.CI(20*floor((hrsub$day_rh)/20),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)

bargraph.CI(2*floor((wfsub$day_wsp)/2),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)
bargraph.CI(2*floor((wfexsub$day_wsp)/2),wfexsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)
bargraph.CI(2*floor((hrsub$day_wsp)/2),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)

bargraph.CI(10*floor((wfsub$press_surf-5)/10),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)
bargraph.CI(10*floor((wfexsub$press_surf-5)/10),wfexsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)
bargraph.CI(10*floor((hrsub$press_surf-5)/10),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)

bargraph.CI(300*floor((wfsub$mixing_ht)/300),wfsub$day_pm25,ylim=c(0,150),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)
bargraph.CI(300*floor((wfexsub$mixing_ht)/300),wfexsub$day_pm25,ylim=c(0,150),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)
bargraph.CI(300*floor((hrsub$mixing_ht)/300),hrsub$day_pm25,ylim=c(0,150),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)

bargraph.CI(300*floor((wfsub$inv2)/300),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)
bargraph.CI(300*floor((wfexsub$inv2)/300),wfexsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)
bargraph.CI(300*floor((hrsub$inv2)/300),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)

bargraph.CI(floor(wfsub$logarea),wfsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)
bargraph.CI(floor(wfexsub$logarea),wfexsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)
bargraph.CI(floor(hrsub$logarea),hrsub$day_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)

#night time (Figure 6)
bargraph.CI(5*floor((wfsub$night_temp)/5),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)
bargraph.CI(5*floor((wfexsub$night_temp)/5),wfexsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)
bargraph.CI(5*floor((hrsub$night_temp)/5),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Temperature (C)",line=2)

bargraph.CI(20*floor((wfsub$night_rh)/20),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)
bargraph.CI(20*floor((wfsub$night_rh)/20),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)
bargraph.CI(20*floor((hrsub$night_rh)/20),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Relative Humidity (%)",line=2)

bargraph.CI(floor((wfsub$night_wsp)),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)
bargraph.CI(floor((wfexsub$night_wsp)),wfexsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)
bargraph.CI(floor((hrsub$night_wsp)),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Wind Speed (km/h)",line=2)

bargraph.CI(10*floor((wfsub$Nextpress-5)/10),wfsub$night_pm25,ylim=c(0,80),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)
bargraph.CI(10*floor((wfexsub$Nextpress-5)/10),wfexsub$night_pm25,ylim=c(0,80),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)
bargraph.CI(10*floor((hrsub$Nextpress-5)/10),hrsub$night_pm25,ylim=c(0,80),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Surface Pressure (Hpa)",line=2)

bargraph.CI(300*floor((wfsub$Nextmixing)/300),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)
bargraph.CI(300*floor((wfexsub$Nextmixing)/300),wfexsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)
bargraph.CI(300*floor((hrsub$Nextmixing)/300),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Mixing Height (m)",line=2)

bargraph.CI(300*floor((wfsub$Nextinv2)/300),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)
bargraph.CI(300*floor((wfexsub$Nextinv2)/300),wfexsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)
bargraph.CI(300*floor((hrsub$Nextinv2)/300),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Inversion Height (m)",line=2)

bargraph.CI(floor(wfsub$logarea),wfsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)
bargraph.CI(floor(wfexsub$logarea),wfexsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)
bargraph.CI(floor(hrsub$logarea),hrsub$night_pm25,ylim=c(0,60),xlab="",ylab="")
title(ylab="PM 2.5",line=2); title(xlab="Plume Area (log)",line=2)


####model of  exceedances with 25 definition####
plumedat$day_ex<-plumedat$day_pm25>25 & plumedat$day_pm25 > plumedat$base_day_pm25
plumedat$night_ex<-plumedat$night_pm25>25 & plumedat$night_pm25 > plumedat$base_night_pm25
table(plumedat$FireType,plumedat$day_ex)
table(plumedat$FireType,plumedat$night_ex)
#fit all level 1 combos
#I have decided not to allow C-haines, favouring mixing height
pm25mult<-glmulti(glm(day_ex~FireType+day_temp+day_wsp+day_rh+press_surf+mixing_ht+logarea+inv2,family=binomial,data=plumedat),level=1,maxsize=3)
pm25mult@crits[1:10]
pm25mult@objects[1:4]

#best model with interactions
#only intestigating firetype interactions
#final model
pm25bin<-glm(day_ex~day_wsp*FireType+day_temp+mixing_ht,family=binomial,data=plumedat)
summary(pm25bin)


#day exceedance model without 201920 fires
pm25mult<-glmulti(glm(day_ex~FireType+day_temp+day_wsp+day_rh+press_surf+mixing_ht+logarea+inv2,family=binomial,data=ex2019sub),level=1,maxsize=5)
pm25mult@crits[1:10]
pm25mult@objects[1:4]
#this is the final model
pm25bin<-glm(day_ex~press_surf+day_temp+day_rh,family=binomial,data=ex2019sub)
summary(pm25bin)
#No interactions



####Figure 7a: Model plots for day model ####
windows(8,3)
par(mfrow=c(1,2))
par(mar=c(3,3,1,1))
#vs ws varying temp and Firetype
preddat<-data.frame("day_temp"=rep(20,100),"day_wsp"=seq(0.5,10.4,0.1),"logarea"=rep(5,100),"inv_height"=rep(150,100),"mixing_ht"=rep(50,100),"FireType"=rep("HR",100))
out1<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(33,100),"day_wsp"=seq(0.5,10.4,0.1),"logarea"=rep(5,100),"inv_height"=rep(150,100),"mixing_ht"=rep(50,100),"FireType"=rep("HR",100))
out2<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(20,100),"day_wsp"=seq(0.5,10.4,0.1),"logarea"=rep(5,100),"inv_height"=rep(150,100),"mixing_ht"=rep(50,100),"FireType"=rep("WF",100))
out3<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(33,100),"day_wsp"=seq(0.5,10.4,0.1),"logarea"=rep(5,100),"inv_height"=rep(150,100),"mixing_ht"=rep(50,100),"FireType"=rep("WF",100))
out4<-predict(pm25bin, preddat, "response", se.fit=T)
plot(c(0,12),c(0,1),cex=0,xlab="",ylab="")
lines(preddat$day_wsp, out1$fit,lwd=2,lty=1,col=1)
lines(preddat$day_wsp, out2$fit,lwd=2,lty=10,col=1)
lines(preddat$day_wsp, out3$fit,lwd=2,lty=1,col=8)
lines(preddat$day_wsp, out4$fit,lwd=2,lty=10,col=8)
title(xlab="Wind Speed (km/hr)",line=2)
title(ylab="Likelihood of Exceedance",line=2)
grid()
legend(6,1,legend=c(" Type / Temperature"," HR / 22 C","HR / 33 C","WF / 22 C","WF / 33 C"),lwd=2,lty=c(0,1,10,1,10),cex=0.7,col=c(0,1,1,8,8))
text(7.3,0.93,"Fire",cex=0.7)

#vs mixing_ht varying ws and Firetype
preddat<-data.frame("day_temp"=rep(27,100),"day_wsp"=rep(1,100),"logarea"=rep(5,100),"inv_height"=seq(1,1500,15),"mixing_ht"=seq(1,1500,15),"FireType"=rep("HR",100))
out1<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(37,100),"day_wsp"=rep(5,100),"logarea"=rep(5,100),"inv_height"=seq(1,1500,15),"mixing_ht"=seq(1,1500,15),"FireType"=rep("HR",100))
out2<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(27,100),"day_wsp"=rep(1,100),"logarea"=rep(5,100),"inv_height"=seq(1,1500,15),"mixing_ht"=seq(1,1500,15),"FireType"=rep("WF",100))
out3<-predict(pm25bin, preddat, "response", se.fit=T)
preddat<-data.frame("day_temp"=rep(37,100),"day_wsp"=rep(5,100),"logarea"=rep(5,100),"inv_height"=seq(1,1500,15),"mixing_ht"=seq(1,1500,15),"FireType"=rep("WF",100))
out4<-predict(pm25bin, preddat, "response", se.fit=T)
plot(c(0,1500),c(0,1),cex=0,xlab="",ylab="")
lines(preddat$mixing_ht, out1$fit,lwd=2,lty=1,col=1)
lines(preddat$mixing_ht, out2$fit,lwd=2,lty=10,col=1)
lines(preddat$mixing_ht, out3$fit,lwd=2,lty=1,col=8)
lines(preddat$mixing_ht, out4$fit,lwd=2,lty=10,col=8)
title(xlab="Mixing Height (m)",line=2)
title(ylab="Likelihood of Exceedance",line=2)
grid()
legend(800,0.5,legend=c(" Type / Wind Speed","HR / 1 km/hr","HR / 5 km/hr","WF / 1 km/hr","WF / 5 km/hr"),lwd=2,lty=c(0,1,10,1,10),cex=0.7,col=c(0,1,1,8,8))
text(960,0.43,"Fire",cex=0.7)


####model of PM night exceedances####
#there are only 3 night exceedances so the previous model did not work. Re-doing with 18 cut-off
plumedat$night_ex<-plumedat$night_pm25>18 & plumedat$night_pm25 > plumedat$base_night_pm25
pm25mult<-glmulti(glm(night_ex~FireType+night_temp+night_wsp+night_rh+Nextpress+logarea+Nextmixing+Nextinv2,family=binomial,data=plumedat),level=1,maxsize=8)
pm25mult@crits[1:10]
pm25mult@objects[1:4]
pm25night<-glm(night_ex~night_wsp+Nextpress+Nextmixing+Nextinv2 +logarea,family=binomial,data=plumedat)
summary(pm25night)
#testing interactions with firetype
#This is the final night model
pm25night<-glm(night_ex~night_wsp*FireType+Nextpress+Nextmixing+Nextinv2 +logarea,family=binomial,data=plumedat)
summary(pm25night)

#testing this model for non-2019 data by fitting the full model and removing non-sig: Pressure effect seems to be a 2019 thing 
pm25mult<-glmulti(glm(night_ex~FireType+night_temp+night_wsp+night_rh+Nextpress+logarea+Nextmixing+Nextinv2,family=binomial,data=ex2019sub),level=1,maxsize=8)
pm25mult@crits[1:10]
pm25mult@objects[1:4]
pm25night<-glm(night_ex~night_wsp*FireType+Nextmixing+logarea,family=binomial,data=ex2019sub)
summary(pm25night)


####Figure 7b (night model) ####
#Wind speed varying fire type and plume area
preddat<-data.frame("night_rh"=rep(74,80),"night_temp"=rep(20,80),"FireType"=rep("HR",80),"Nextpress"=rep(1013,80),"night_wsp"=seq(0.1,8,0.1),"Nextmixing"=rep(120,80),"Nextinv2"=rep(154,80),"logarea"=rep(5,80))
out1<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,80),"night_temp"=rep(20,80),"FireType"=rep("HR",80),"Nextpress"=rep(1013,80),"night_wsp"=seq(0.1,8,0.1),"Nextmixing"=rep(120,80),"Nextinv2"=rep(154,80),"logarea"=rep(8,80))
out2<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,80),"night_temp"=rep(20,80),"FireType"=rep("WF",80),"Nextpress"=rep(1013,80),"night_wsp"=seq(0.1,8,0.1),"Nextmixing"=rep(120,80),"Nextinv2"=rep(154,80),"logarea"=rep(5,80))
out3<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,80),"night_temp"=rep(20,80),"FireType"=rep("WF",80),"Nextpress"=rep(1013,80),"night_wsp"=seq(0.1,8,0.1),"Nextmixing"=rep(120,80),"Nextinv2"=rep(154,80),"logarea"=rep(8,80))
out4<-predict(pm25night, preddat, "response", se.fit=T)
plot(c(0,8),c(0,1),cex=0,xlab="",ylab="")
grid()
lines(preddat$night_wsp, out1$fit,lwd=2,lty=1,col=1)
lines(preddat$night_wsp, out2$fit,lwd=2,lty=10,col=1)
lines(preddat$night_wsp, out3$fit,lwd=2,lty=1,col=8)
lines(preddat$night_wsp, out4$fit,lwd=2,lty=10,col=8)
title(xlab="Wind Speed (km/hr)",line=2)
title(ylab="Likelihood of Exceedance",line=2)
legend(1.5,1,legend=c("     / Plume Area","HR / 150 ha","HR / 3000 ha","WF / 150 ha","WF / 3000 ha"),lwd=2,lty=c(0,1,10,1,10),cex=0.75,col=c(0,1,1,8,8))
text(2.4,0.92,"Fire Type",cex=0.75)

#surface pressure varying mixing_ht and inversion
preddat<-data.frame("night_rh"=rep(74,36),"night_temp"=rep(20,36),"FireType"=rep("WF",36),"Nextpress"=seq(994,1029,1),"night_wsp"=rep(1.3,36),"Nextmixing"=rep(60,36),"Nextinv2"=rep(120,36),"logarea"=rep(6.3,36))
out1<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,36),"night_temp"=rep(20,36),"FireType"=rep("WF",36),"Nextpress"=seq(994,1029,1),"night_wsp"=rep(1.3,36),"Nextmixing"=rep(60,36),"Nextinv2"=rep(450,36),"logarea"=rep(6.3,36))
out2<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,36),"night_temp"=rep(20,36),"FireType"=rep("WF",36),"Nextpress"=seq(994,1029,1),"night_wsp"=rep(1.3,36),"Nextmixing"=rep(600,36),"Nextinv2"=rep(120,36),"logarea"=rep(6.3,36))
out3<-predict(pm25night, preddat, "response", se.fit=T)
preddat<-data.frame("night_rh"=rep(74,36),"night_temp"=rep(20,36),"FireType"=rep("WF",36),"Nextpress"=seq(994,1029,1),"night_wsp"=rep(1.3,36),"Nextmixing"=rep(600,36),"Nextinv2"=rep(450,36),"logarea"=rep(6.3,36))
out4<-predict(pm25night, preddat, "response", se.fit=T)
plot(c(994,1029),c(0,1),cex=0,xlab="",ylab="")
grid()
lines(preddat$Nextpress, out1$fit,lwd=2,lty=1,col=1)
lines(preddat$Nextpress, out2$fit,lwd=2,lty=10,col=1)
lines(preddat$Nextpress, out3$fit,lwd=2,lty=1,col=8)
lines(preddat$Nextpress, out4$fit,lwd=2,lty=10,col=8)
title(xlab="Surface Pressure",line=2)
title(ylab="Likelihood of Exceedance",line=2)
legend(1012,1,legend=c(" Ht / Inversion Ht","60 m / 120 m","60 m / 450 m","600 m / 120 m","600 m /450 m"),lwd=2,lty=c(0,1,10,1,10),cex=0.75,col=c(0,1,1,8,8))
text(1015,0.92,"Mixing",cex=0.75)




